==> tecfy_core_package-0.1.26.tar.gz: lib/models/entity/property_text.model.dart <==
part of tecfy_core_client_package;

class PropertyText extends Property {
  int maxLength = 25000;
  int minLength = 0;
  int lines = 1;

  bool isMultiLine = false;

  bool isPassword = false;
  bool isEmail = false;
  bool isBarcode = false;

  PropertyText(
      {dbName,
      nameAr,
      nameEn,
      this.isMultiLine = false,
      this.isPassword = false,
      this.isEmail = false,
      this.isBarcode = false,
      this.lines = 1,
      this.maxLength = 25000,
      this.minLength = 0})
      : super(dbName: dbName, nameAr: nameAr, nameEn: nameEn) {
    super.propertyType = PropertyTypes.Text;
  }

  PropertyText.fromMap(Map row) : super.fromMap(row) {
    maxLength = row['maxLength'] ?? 25000;
    minLength = row['minLength'] ?? 0;
    lines = row['lines'] ?? 1;
    isMultiLine = row['isMultiLine'] ?? false;
    isPassword = row['isPassword'] ?? false;
    isBarcode = row['isBarcode'] ?? false;
    isEmail = row['isEmail'] ?? false;
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    if (isRequired && data == null)
      return OperationResult(
          success: false, message: "$name ($dbName): Text Value Required");

    if (data != null && (!(data is String) || (isRequired && data.length == 0)))
      return OperationResult(
          success: false, message: "$name ($dbName): Text Value Required");

    if (data != null && data.length > maxLength)
      return OperationResult(
          success: false, message: "$name ($dbName): Max Length exceped");

    if (data != null && data.length < minLength)
      return OperationResult(
          success: false, message: "$name ($dbName): Min Length not reached");

    return OperationResult(success: true);
  }

  Widget getDisplayWidget(Map data,
      {double size = 12, Color color = Colors.black}) {
    return Text(data[dbName]?.toString() ?? '',
        style: TextStyle(fontSize: size, color: color));
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null && data[dbName].toString().isNotEmpty)
      return false;
    if (defaultString.isNotEmpty) {
      data[dbName] = defaultString;
      return true;
    }
    return false;
  }
}

==> tecfy_core_package-0.1.28.tar.gz: lib/models/entity/property_text.model.dart <==
part of tecfy_core_client_package;

class PropertyText extends Property {
  int maxLength = 25000;
  int minLength = 0;
  int lines = 1;

  bool isMultiLine = false;

  bool isPassword = false;
  bool isEmail = false;
  bool isBarcode = false;

  PropertyText(
      {dbName,
      nameAr,
      nameEn,
      this.isMultiLine = false,
      this.isPassword = false,
      this.isEmail = false,
      this.isBarcode = false,
      this.lines = 1,
      this.maxLength = 25000,
      this.minLength = 0})
      : super(dbName: dbName, nameAr: nameAr, nameEn: nameEn) {
    super.propertyType = PropertyTypes.Text;
  }

  PropertyText.fromMap(Map row) : super.fromMap(row) {
    maxLength = row['maxLength'] ?? 25000;
    minLength = row['minLength'] ?? 0;
    lines = row['lines'] ?? 1;
    isMultiLine = row['isMultiLine'] ?? false;
    isPassword = row['isPassword'] ?? false;
    isBarcode = row['isBarcode'] ?? false;
    isEmail = row['isEmail'] ?? false;
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    if (isRequired && data == null)
      return OperationResult(
          success: false, message: "$name ($dbName): Text Value Required");

    if (data != null && (!(data is String) || (isRequired && data.length == 0)))
      return OperationResult(
          success: false, message: "$name ($dbName): Text Value Required");

    if (data != null && data.length > maxLength)
      return OperationResult(
          success: false, message: "$name ($dbName): Max Length exceped");

    if (data != null && data.length < minLength)
      return OperationResult(
          success: false, message: "$name ($dbName): Min Length not reached");

    return OperationResult(success: true);
  }

  Widget getDisplayWidget(Map data,
      {double size = 12, Color color = Colors.black}) {
    return Text(data[dbName]?.toString() ?? '',
        style: TextStyle(fontSize: size, color: color));
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null && data[dbName].toString().isNotEmpty)
      return false;
    if (defaultString?.isNotEmpty ?? false) {
      data[dbName] = defaultString;
      return true;
    }
    return false;
  }
}
